@@ -5,10 +5,11 @@
 
 int main( int argc, char * argv[] ) ;
 char *createOutputFileName( char *inputFileName ) ;
-void processFile( char *inputFileName, char *outputFileName, char *docTitle ) ;
+void processFile( char *inputFileName, char *outputFileName, char *docTitle,
+                  const char *docHeader, const char *docFooter ) ;
 char *getCodeLine( void ) ;
-void print_top( char *docTitle, char *s ) ;
-void print_bottom( void ) ;
+void print_top( char *docTitle, char *s , const char *docHeader) ;
+void print_bottom( const char *docFooter ) ;
 void generate( const char *s ) ;
 void generate( const char *s, int start, int end ) ;
 void generateln( const char *s ) ;
